==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/nb.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Snittbelastning",
    "Last minute" : "Siste minutt",
    "Memory info not available" : "Minneinformasjon er ikke tilgjengelig",
    "Total" : "Totalt",
    "Current usage" : "Nåværende bruk",
    "Users" : "Brukere",
    "Groups" : "Grupper",
    "Links" : "Lenker",
    "Federated sent" : "«Forent sendt» - delingen sendt eksternt",
    "Federated received" : "«Forent mottatt» - en ekstern deling mottatt",
    "Copy" : "Kopier",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Monitoring" : "Overvåker",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Gir nyttig serverinformasjon, som CPU-belastning, RAM-bruk, diskbruk, antall brukere, ned mere.",
    "Files:" : "Filer:",
    "Active users" : "Aktive brukere",
    "Shares" : "Delinger",
    "PHP" : "PHP",
    "Version:" : "Versjon:",
    "Memory Limit:" : "Minnegrense:",
    "Max Execution Time:" : "Maks. kjøringstid:",
    "Upload max size:" : "Maks. opplastingstørrelse:",
    "Database" : "Database",
    "Type:" : "Type:",
    "Size:" : "Størrelse:",
    "External monitoring tool" : "Eksternt overvåkingsverktøy",
    "Last 24 hours" : "Siste 24 timer",
    "Last 1 hour" : "Siste time",
    "Last 5 mins" : "Siste 5 minutter",
    "CPU load" : "CPU last",
    "Memory usage" : "Minnebruk",
    "Storage" : "Lagring",
    "Users:" : "Brukere:",
    "Apps installed:" : "Apper installert:",
    "Apps updates available:" : "App-oppdateringer tilgjengelig:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/nb.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Snittbelastning",
    "Last minute" : "Siste minutt",
    "Memory info not available" : "Minneinformasjon er ikke tilgjengelig",
    "Total" : "Totalt",
    "Current usage" : "Nåværende bruk",
    "Users" : "Brukere",
    "Groups" : "Grupper",
    "Links" : "Lenker",
    "Federated sent" : "«Forent sendt» - delingen sendt eksternt",
    "Federated received" : "«Forent mottatt» - en ekstern deling mottatt",
    "24 hours" : "24 timer",
    "1 hour" : "1 time",
    "Copy" : "Kopier",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "System" : "System",
    "Monitoring" : "Overvåker",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Gir nyttig serverinformasjon, som CPU-belastning, RAM-bruk, diskbruk, antall brukere, ned mere.",
    "Size" : "Størrelse",
    "Files:" : "Filer:",
    "Hostname" : "Servernavn",
    "Status" : "Status",
    "Active users" : "Aktive brukere",
    "Shares" : "Delinger",
    "PHP" : "PHP",
    "Version:" : "Versjon:",
    "Memory Limit:" : "Minnegrense:",
    "Max Execution Time:" : "Maks. kjøringstid:",
    "Upload max size:" : "Maks. opplastingstørrelse:",
    "Database" : "Database",
    "Type:" : "Type:",
    "Size:" : "Størrelse:",
    "External monitoring tool" : "Eksternt overvåkingsverktøy",
    "Last 24 hours" : "Siste 24 timer",
    "Last 1 hour" : "Siste time",
    "Last 5 mins" : "Siste 5 minutter",
    "CPU load" : "CPU last",
    "Memory usage" : "Minnebruk",
    "Storage" : "Lagring",
    "Users:" : "Brukere:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Apper installert:",
    "Apps updates available:" : "App-oppdateringer tilgjengelig:"
},
"nplurals=2; plural=(n != 1);");
